/*
 * Copyright 2018-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.drivers.barefoot.pro;

import org.onosproject.drivers.barefoot.TofinoPipelineProgrammable;
import org.onosproject.net.behaviour.PiPipelineProgrammable;
import org.onosproject.net.config.NetworkConfigService;
import org.onosproject.net.pi.model.PiPipeconf;

import java.util.concurrent.CompletableFuture;

/**
 * Implementation of the PiPipelineProgrammable behaviour for a Tofino-based
 * switch.
 */
public class TofinoProPipelineProgrammable
        extends TofinoPipelineProgrammable
        implements PiPipelineProgrammable {

    @Override
    public CompletableFuture<Boolean> deployPipeconf(PiPipeconf pipeconf) {
        return super.deployPipeconf(pipeconf).thenApplyAsync(result -> {
            if (result) {
                doPortconfig();
            }
            return result;
        });
    }

    private void doPortconfig() {
        new TofinoPortConfigurator(handler().get(NetworkConfigService.class))
                .setupPorts(data().deviceId());
    }
}
